@@ -68,13 +68,15 @@ class _LuaDNSLexiconClient(dns_common_lexicon.LexiconClient):
     def __init__(self, email, token, ttl):
         super(_LuaDNSLexiconClient, self).__init__()
 
-        self.provider = luadns.Provider({
-            'provider_name': 'luadns',
+        config = dns_common_lexicon.build_lexicon_config('luadns', {
+            'ttl': ttl,
+        }, {
             'auth_username': email,
             'auth_token': token,
-            'ttl': ttl,
         })
 
+        self.provider = luadns.Provider(config)
+
     def _handle_http_error(self, e, domain_name):
         hint = None
         if str(e).startswith('401 Client Error: Unauthorized for url:'):
